@@ -1,7 +1,7 @@
 #!/bin/sh
 # This file is part of osso-app-killer.
 #
-# Copyright (C) 2005-2006 Nokia Corporation. All rights reserved.
+# Copyright (C) 2005-2007 Nokia Corporation. All rights reserved.
 #
 # Contact: Kimmo Hmlinen <kimmo.hamalainen@nokia.com>
 #
@@ -19,6 +19,13 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
+empty_file()
+{
+  rm -f $1
+  touch $1
+  chmod ugo+rw $1
+}
+
 cd /etc/osso-af-init/gconf-dir
 if [ $? = 0 ]; then
   for d in `ls`; do
@@ -29,7 +36,18 @@ if [ $? = 0 ]; then
       if [ "x$CUD" != "x" ]; then
         for f in `find system -name *.xml`; do
           echo "$0: removing $f"
-          rm -f $f
+          empty_file $f
+        done
+        continue
+      elif [ "x$CUD" = "x" ]; then
+        for f in `find system -name *.xml`; do
+          # in ROS, paths having 'system/bluetooth' are preserved
+          echo "$f" | grep -e 'system\/bluetooth' > /dev/null
+          if [ $? = 0 ]; then
+            continue
+          fi
+          echo "$0: removing $f"
+          empty_file $f
         done
         continue
       fi
@@ -37,13 +55,13 @@ if [ $? = 0 ]; then
       # special handling for subdirectory 'apps'
       if [ "x$CUD" = "x" ]; then
         for f in `find apps -name *.xml`; do
-          # in RFS, paths having 'telepathy' are preserved
+          # in ROS, paths having 'telepathy' are preserved
           echo "$f" | grep -e 'telepathy' > /dev/null
           if [ $? = 0 ]; then
             continue
           fi
           echo "$0: removing $f"
-          rm -f $f
+          empty_file $f
         done
         continue
       fi
